OC.L10N.register(
    "recommendations",
    {
    "Recently commented" : "Comentado recentemente",
    "Recently edited" : "Editado recentemente",
    "Recently shared" : "Compartilhado recentemente",
    "Recommendations" : "Recomendações",
    "Shows recommended files" : "Exibir arquivos recomendados",
    "Shows recommended files for quick access of files and folders with recent activity" : "Exibir arquivos recomendados para acesso rápido em arquivos e pastas com atividade recente",
    "Enabled" : "Ativado"
},
"nplurals=2; plural=(n > 1);");
